@@ -1,7 +1,35 @@
-from datetime import datetime, date
+from datetime import datetime, timezone
 import numbers
 
 
+def localize_datetime(dt):
+    """
+    Localize datetime to local timezone.
+
+    Assume naive datetimes to be UTC timezones, while taking care of the
+    specified timezone in case `time` is aware.
+
+    Returns a naive datetime.
+
+    Parameters
+    ----------
+    dt : datetime.datetime
+        datetime object to localize
+
+    Returns
+    -------
+    datetime.datetime
+        the localized naive datetime object
+    """
+    #  In order to make the conversion:
+    #  - make datetime object aware of timezone
+    #  - update timezone to local
+    #  - cast to naïve timezone again
+    if dt.tzinfo is None:
+        dt = dt.replace(tzinfo=timezone.utc)
+    return dt.astimezone().replace(tzinfo=None)
+
+
 def _parse_time_from_input(time, name=""):
     """
     parse time representation into a time object
@@ -26,7 +54,7 @@ def _parse_time_from_input(time, name=""):
     elif isinstance(time, numbers.Real):
         return datetime.fromtimestamp(time)
     elif isinstance(time, datetime):
-        return time
+        return localize_datetime(time)
     else:
         name = name + " " if name else ""
         msg = "%stype not recognised: not a known time representation"
